==> haskell-cryptohash-conduit-0.1.1-51-i686.pkg.tar.xz: usr/share/haskell/register/haskell-cryptohash-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptohash-conduit
version: 0.1.1
id: cryptohash-conduit-0.1.1-ATiPQmj9KDC8jVT97nz9SC
key: cryptohash-conduit-0.1.1-ATiPQmj9KDC8jVT97nz9SC
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: http://github.com/vincenthz/hs-cryptohash-conduit
synopsis: cryptohash conduit
description:
    Support all the @cryptohash@ package using conduits from
    the @conduit@ package.
category: Cryptography, Conduit
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Crypto.Hash.Conduit
abi: 5f9d5a6248b1bb32d45fa2116259fb3f
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/cryptohash-conduit-0.1.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/cryptohash-conduit-0.1.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/cryptohash-conduit-0.1.1
hs-libraries: HScryptohash-conduit-0.1.1-ATiPQmj9KDC8jVT97nz9SC
depends:
    base-4.9.0.0 bytestring-0.10.8.1
    conduit-1.2.8-D9dRTYSavk8HJ0UStkfE43
    conduit-extra-1.1.15-FSdOtryxOIZL6vIsq9443u
    cryptohash-0.11.9-DHI6HEU0ngdHLXXk1TIe9A
    resourcet-1.1.9-J17FkGhZ2yV57Ehh8hruPC transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-cryptohash-conduit/html/cryptohash-conduit.haddock
haddock-html: /usr/share/doc/haskell-cryptohash-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cryptohash-conduit-0.1.1-52-i686.pkg.tar.xz: usr/share/haskell/register/haskell-cryptohash-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptohash-conduit
version: 0.1.1
id: cryptohash-conduit-0.1.1-IsYhG9U4Fmi54A8lfoYeKQ
key: cryptohash-conduit-0.1.1-IsYhG9U4Fmi54A8lfoYeKQ
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: http://github.com/vincenthz/hs-cryptohash-conduit
synopsis: cryptohash conduit
description:
    Support all the @cryptohash@ package using conduits from
    the @conduit@ package.
category: Cryptography, Conduit
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Crypto.Hash.Conduit
abi: c9f71475cc857369a90d7025795fc383
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/cryptohash-conduit-0.1.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/cryptohash-conduit-0.1.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/cryptohash-conduit-0.1.1
hs-libraries: HScryptohash-conduit-0.1.1-IsYhG9U4Fmi54A8lfoYeKQ
depends:
    base-4.9.0.0 bytestring-0.10.8.1
    conduit-1.2.8-D9dRTYSavk8HJ0UStkfE43
    conduit-extra-1.1.15-824iGXaP3tL2Ph4TH8girc
    cryptohash-0.11.9-DHI6HEU0ngdHLXXk1TIe9A
    resourcet-1.1.9-J17FkGhZ2yV57Ehh8hruPC transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-cryptohash-conduit/html/cryptohash-conduit.haddock
haddock-html: /usr/share/doc/haskell-cryptohash-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
